@@ -1,11 +1,11 @@
-from root_numpy import (
+from _root_numpy import (
     root2array, root2rec,
     tree2array, tree2rec,
     array2tree, array2root,
     list_trees, list_branches, list_structures,
     fill_array, fill_hist,
-    random_sample)
-from root_numpy_warnings import RootNumpyWarning, RootNumpyUnconvertibleWarning
+    random_sample, array, matrix)
+from _warnings import RootNumpyWarning, RootNumpyUnconvertibleWarning
 from utils import stretch, blockwise_inner_join
 from info import __version__
 
@@ -19,6 +19,8 @@ __all__ = [
     'fill_array',
     'fill_hist',
     'random_sample',
+    'array',
+    'matrix',
     'list_trees',
     'list_branches',
     'list_structures',
